@@ -25,21 +25,12 @@ from .. import spatial
 class GeneralFIRE(_Base):
     name = "GeneralFIRE"
     version = "1.0"
-    def __init__(self):
-        _Base.__init__(self)
-        self.default_objects["Source"]["coordinates"].Position = [0,0,1]
-        self.default_objects["Source"]["system"] = spatial.Coordinates.System.Spherical
 
-    def add_metadata(self, dataset):
-        _Base.add_general_defaults(dataset)
+    def add_metadata(self, database):
+        super().add_metadata(database)
 
-        dataset.SOFAConventions = self.name
-        dataset.SOFAConventionsVersion = self.version
-        dataset.DataType = "FIRE"
-        dataset.RoomType = "free field"
+        database.Metadata.set_attribute("SOFAConventions", self.name)
+        database.Metadata.set_attribute("SOFAConventionsVersion", self.version)
+
+        database.Data.Type = "FIRE"
         return
-
-    def set_default_spatial_values(self, spobj):
-        _Base._set_default_spatial_values(self, spobj)
-        return
-
